@@ -893,11 +893,19 @@ magnifier_reset_struts_at_idle (gpointer data)
 	if (data)
 	{
 		Magnifier *magnifier = MAGNIFIER (data);
+#if GTK_CHECK_VERSION (2,19,5)
+		if (magnifier->priv &&
+		    gtk_widget_get_realized (magnifier->priv->w) &&
+		    gmag_gs_check_set_struts (magnifier)) {
+			return FALSE;
+		}
+#else
 		if (magnifier->priv &&
 		    GTK_WIDGET_REALIZED (magnifier->priv->w) && 
 		    gmag_gs_check_set_struts (magnifier)) {
 			return FALSE;
 		}
+#endif
 	}
 	return TRUE;
 }
