@@ -158,9 +158,15 @@ gmag_gs_check_set_struts (Magnifier *magnifier)
 		return TRUE;
 #endif
 
+#if GTK_CHECK_VERSION (2,19,5)
+	if (magnifier &&
+	    magnifier->priv && magnifier->priv->w && gtk_widget_get_realized (magnifier->priv->w) &&
+	    magnifier->priv->w->window) 
+#else
 	if (magnifier &&
 	    magnifier->priv && magnifier->priv->w && GTK_WIDGET_REALIZED (magnifier->priv->w) &&
 	    magnifier->priv->w->window) 
+#endif
 	{
 		Atom atom_strut = gdk_x11_get_xatom_by_name ("_NET_WM_STRUT");
 		Atom atom_strut_partial = gdk_x11_get_xatom_by_name ("_NET_WM_STRUT_PARTIAL");
@@ -248,8 +254,13 @@ gmag_gs_reset_overlay_at_idle (gpointer data)
 		return FALSE;
 	if (data) {
 		Magnifier *magnifier = MAGNIFIER (data);
+#if GTK_CHECK_VERSION (2,19,5)
 		if (magnifier->priv && magnifier->priv->w &&
-		    GTK_WIDGET_REALIZED (magnifier->priv->w)) 
+		    gtk_widget_get_realized (magnifier->priv->w))
+#else
+		if (magnifier->priv && magnifier->priv->w &&
+		    GTK_WIDGET_REALIZED (magnifier->priv->w))
+#endif
 			if (magnifier->priv->w->window) {
 #ifdef HAVE_OVERLAY
 				gint      x, y, over_w, over_h;
